# TODO: separate gltpd to -server package, add init script (requires portmap)

%define major		4
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

# comment out if not pre-release
#define beta	beta2

# rel for bumping
%define rel	2

Summary:	Open Geographic Datastore Interface
Name:		ogdi
Version:	4.1.1
Release:	%mkrel %{?beta:0.%beta.}%{rel}
License:	BSD
Group:		Sciences/Geosciences
URL:		https://ogdi.sourceforge.net/
Source0:	https://github.com/libogdi/ogdi/releases/download/ogdi_4_1_1/%{name}-%{version}%{?beta:.%beta}.tar.gz
Source1:	https://ogdi.sourceforge.net/ogdi.pdf

Patch1:		ogdi-3.2.0.beta2-fix-str-fmt.patch
#(eatdirt) fix missing links
Patch20:	ogdi-4.0.0-sincos.patch
Patch21:	ogdi-4.0.0-dl.patch

BuildRequires:	pkgconfig(expat)
BuildRequires:	pkgconfig(libtirpc)
BuildRequires:	pkgconfig(tcl)
BuildRequires:	pkgconfig(zlib)

# ODBC driver has been removed in 4.1.1 without replacement
Obsoletes:	%{name}-odbc < 4.1.1

%description
OGDI is the Open Geographic Datastore Interface. OGDI is an
application programming interface (API) that uses a standardized
access methods to work in conjunction with GIS software packages (the
application) and various geospatial data products. OGDI uses a
client/server architecture to facilitate the dissemination of
geospatial data products over any TCP/IP network, and a
driver-oriented approach to facilitate access to several geospatial
data products/formats.

%package -n %{libname}
Summary:	Open Geographic Datastore Interface - library
License:	BSD style
Group:		Sciences/Geosciences

%description -n %{libname}
OGDI is the Open Geographic Datastore Interface. OGDI is an
application programming interface (API) that uses a standardized
access methods to work in conjunction with GIS software packages (the
application) and various geospatial data products. OGDI uses a
client/server architecture to facilitate the dissemination of
geospatial data products over any TCP/IP network, and a
driver-oriented approach to facilitate access to several geospatial
data products/formats.

This package contains just the library required by applications using the
Open Geographic Datastore Interface.

%package -n %{develname}
Summary:	OGDI header files and documentation
Group:		Sciences/Geosciences
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
OGDI header files and developer's documentation.

%package -n tcl-ogdi
Summary:	TCL wrapper for OGDI
Summary(pl):	Interfejs TCL do OGDI
Group:		Sciences/Geosciences
Requires:	%{name} = %{version}-%{release}

%description -n tcl-ogdi
TCL wrapper for OGDI.

%prep

%setup -q -n %{name}-%{version}%{?beta:.%beta}
%patch -P 1 -p0
%patch -P 20 -p1 -b .orig
%patch -P 21 -p1 -b .orig

cp -f %{SOURCE1} .

# force system libs
rm -rf proj
rm -rf external/{expat,rpc_win32,zlib}

%build

TOPDIR=`pwd`; TARGET=Linux; export TOPDIR TARGET
INST_LIB=%{_libdir}/;export INST_LIB
export CFG=debug # for -g

# do not compile with ssp. it will trigger internal bugs (to_fix_upstream)
#OPT_FLAGS=`echo $RPM_OPT_FLAGS|sed -e 's/-Wp,-D_FORTIFY_SOURCE=2//g'`
#export CFLAGS="$OPT_FLAGS -fPIC -DPIC -DDONT_TD_VOID -DUSE_TERMIO"
export CFLAGS="%{optflags} -std=gnu17"
export LDFLAGS="%{ldflags}"
%configure \
	--with-binconfigs \
	--with-expat \
	--with-zlib

# use the generated .mak file ...
cp -af config/linux.mak{,.old}
cp -af config/{L,l}inux.mak

# make doesn't survive a parallell build, so stop that...
%__make

%__make -C ogdi/tcl_interface \
	TCL_LINKLIB="-ltcl"

%__make -C contrib/gdal

%install
# export env
TOPDIR=`pwd`; TARGET=Linux; export TOPDIR TARGET

%make_install \
	INST_INCLUDE=%{buildroot}%{_includedir}/%{name} \
	INST_LIB=%{buildroot}%{_libdir} \
	INST_BIN=%{buildroot}%{_bindir}

#plugin install
%make_install -C ogdi/tcl_interface \
	INST_LIB=%{buildroot}%{_libdir}
%make_install -C contrib/gdal \
	INST_LIB=%{buildroot}%{_libdir}

# remove example binary
rm -rf %{buildroot}%{_bindir}/example?

# we have multilib ogdi-config
%if "%{_lib}" == "lib"
%define cpuarch 32
%else
%define cpuarch 64
%endif

# fix file(s) for multilib issue
touch -r ogdi-config.in ogdi-config

# install pkgconfig file and ogdi-config
mkdir -p %{buildroot}%{_libdir}/pkgconfig
install -p -m 644 ogdi.pc %{buildroot}%{_libdir}/pkgconfig/
install -p -m 755 ogdi-config %{buildroot}%{_bindir}/ogdi-config-%{cpuarch}
# ogdi-config wrapper for multiarch
cat > %{buildroot}%{_bindir}/%{name}-config <<EOF
#!/bin/bash

ARCH=\$(uname -m)
case \$ARCH in
x86_64 | ppc64 | ia64 | s390x | sparc64 | alpha | alphaev6 | aarch64 )
ogdi-config-64 \${*}
;;
*)
ogdi-config-32 \${*}
;;
esac
EOF
chmod 755 %{buildroot}%{_bindir}/%{name}-config
touch -r ogdi-config.in %{buildroot}%{_bindir}/%{name}-config

%files
%doc LICENSE NEWS ChangeLog README
%{_bindir}/gltpd
%{_bindir}/ogdi_*
%dir %{_libdir}/ogdi
%{_libdir}/%{name}/libadrg.so
%{_libdir}/%{name}/libgdal.so
%{_libdir}/%{name}/libremote.so
%{_libdir}/%{name}/librpf.so
%{_libdir}/%{name}/libskeleton.so
%{_libdir}/%{name}/libvrf.so

%files -n %{libname}
%{_libdir}/libogdi.so.%{major}{,.*}

%files -n %{develname}
%doc ogdi.pdf
%doc ogdi/examples/example1/example1.c
%doc ogdi/examples/example2/example2.c
%{_bindir}/%{name}-config
%{_bindir}/%{name}-config-%{cpuarch}
%{_libdir}/pkgconfig/%{name}.pc
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_libdir}/libogdi.so

%files -n tcl-ogdi
%{_libdir}/ogdi/libecs_tcl.so


%changelog
* Thu May 22 2025 ns80 <ns80> 4.1.1-2.mga10
+ Revision: 2185693
- try to fix building with GCC 15

* Wed Oct 16 2024 daviddavid <daviddavid> 4.1.1-1.mga10
+ Revision: 2107598
- Update to 4.1.1
- Remove odbc subpackage

* Sat Mar 19 2022 umeabot <umeabot> 4.1.0-4.mga9
+ Revision: 1800038
- Mageia 9 Mass Rebuild

* Fri Dec 11 2020 wally <wally> 4.1.0-3.mga8
+ Revision: 1655463
- BR libtirpc

* Sun Feb 16 2020 umeabot <umeabot> 4.1.0-2.mga8
+ Revision: 1535469
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Oct 11 2019 daviddavid <daviddavid> 4.1.0-1.mga8
+ Revision: 1451898
- new version: 4.1.0

* Thu Mar 07 2019 eatdirt <eatdirt> 4.0.0-1.mga7
+ Revision: 1372181
- Upgrade to version 4.0.0

* Sun Sep 23 2018 umeabot <umeabot> 3.2.0-2.mga7
+ Revision: 1299961
- Mageia 7 Mass Rebuild
+ kekepower <kekepower>
- Use new make macros

* Sat Mar 17 2018 wally <wally> 3.2.0-1.mga7
+ Revision: 1210063
- new version 3.2.0
- drop unneeded proj patch
- add aarch64 support

* Sat Mar 17 2018 daviddavid <daviddavid> 3.2.0-0.beta2.14.mga7
+ Revision: 1210012
- rebuild for new proj 5.0.0

* Tue Oct 31 2017 eatdirt <eatdirt> 3.2.0-0.beta2.13.mga7
+ Revision: 1175130
- Rebuild for new libproj

* Thu May 19 2016 eatdirt <eatdirt> 3.2.0-0.beta2.12.mga6
+ Revision: 1016889
- Rebuild for new libproj

* Fri Feb 12 2016 umeabot <umeabot> 3.2.0-0.beta2.11.mga6
+ Revision: 956509
- Mageia 6 Mass Rebuild

* Mon Oct 05 2015 daviddavid <daviddavid> 3.2.0-0.beta2.10.mga6
+ Revision: 886292
- rebuild for new tcl 8.6.4

* Wed Oct 15 2014 umeabot <umeabot> 3.2.0-0.beta2.9.mga5
+ Revision: 750420
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.2.0-0.beta2.8.mga5
+ Revision: 683163
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 3.2.0-0.beta2.7.mga4
+ Revision: 521224
- Mageia 4 Mass Rebuild

* Sat Jan 19 2013 fwang <fwang> 3.2.0-0.beta2.6.mga3
+ Revision: 389699
- add fedora patch to fix build
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue May 08 2012 fwang <fwang> 3.2.0-0.beta2.5.mga2
+ Revision: 234872
- drop invalid provides

* Thu Dec 08 2011 fwang <fwang> 3.2.0-0.beta2.4.mga2
+ Revision: 178878
- rebuild for new odbc

* Wed Jul 06 2011 fwang <fwang> 3.2.0-0.beta2.3.mga2
+ Revision: 119196
- rebuild for new tcl

* Thu Mar 24 2011 ennael <ennael> 3.2.0-0.beta2.2.mga1
+ Revision: 76965
- clean spec file
- imported package ogdi


* Tue Dec 07 2010 Oden Eriksson <oeriksson@mandriva.com> 3.2.0-0.beta2.2mdv2011.0
+ Revision: 613170
- the mass rebuild of 2010.1 packages

* Wed Feb 17 2010 Emmanuel Andry <eandry@mandriva.org> 3.2.0-0.beta2.1mdv2010.1
+ Revision: 507085
- New version 3.2.0 beta2
- use huge part of fedora spec file
- drop p0 (fixed upstream)
- diff p1 to fix string format not litteral
- now uses major
- update files list

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Sat Dec 06 2008 Adam Williamson <awilliamson@mandriva.org> 3.1.5-5mdv2009.1
+ Revision: 311056
- 'BSD-style' is BSD (license)
- rebuild for new tcl

* Wed Jul 30 2008 Thierry Vignaud <tv@mandriva.org> 3.1.5-4mdv2009.0
+ Revision: 254396
- rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Mon Dec 17 2007 Thierry Vignaud <tv@mandriva.org> 3.1.5-2mdv2008.1
+ Revision: 130867
- kill re-definition of %%buildroot on Pixel's request


* Mon Jan 02 2006 Oden Eriksson <oeriksson@mandriva.com> 3.1.5-2mdk
- rebuilt against soname aware deps (tcl/tk)
- fix deps
- pass -fPIC to CFLAGS to make it compile on x86_64

* Fri Dec 30 2005 Buchan Milne <bgmilne@mandriva.org> 3.1.5-1mdk
- New release 3.1.5
- rpmbuildupdate-able
- fix build of odbc driver
- %%mkrel

* Mon Jul 14 2003 Buchan Milne <bgmilne@linux-mandrake.com> 3.1.2-1mdk
- Package from PLD updated to 3.1.2

